@@ -16,12 +16,20 @@
 
 import functools
 
+from oslo_config import cfg
+from oslo_policy import opts
 from oslo_policy import policy
 
 from zaqar.common import policies
 
 ENFORCER = None
 
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(cfg.CONF, DEFAULT_POLICY_FILE)
+
 
 def setup_policy(conf):
     global ENFORCER
